==> 1.0.23.tar.gz: android/src/main/java/com/aruistar/flutter/plugin/flutter_nfc_mifare/FlutterNfcMifarePlugin.java <==
package com.aruistar.flutter.plugin.flutter_nfc_mifare;

import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.nfc.NfcAdapter;
import android.nfc.Tag;
import android.nfc.tech.MifareClassic;
import android.util.Log;
import android.widget.Toast;
import android.app.Activity;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.ExecutionException;

/**
 * FlutterNfcMifarePlugin
 */
public class FlutterNfcMifarePlugin implements FlutterPlugin, ActivityAware , MethodCallHandler/*, PluginRegistry.NewIntentListener*/ {

    private static NfcAdapter mNfcAdapter;
    private static PendingIntent mPendingIntent;
    private Activity activity;
    private static Context context;
    static MethodChannel channel = null;
    static MifareClassic currentMF1 = null;
    private static FlutterNfcMifarePlugin pluginbk;
    /**
     * Plugin registration.
     */

     @Override
     public void onAttachedToEngine(FlutterPluginBinding binding) {
        channel = new MethodChannel(binding.getFlutterEngine().getDartExecutor(), "flutter_nfc_mifare");
        FlutterNfcMifarePlugin plugin = new FlutterNfcMifarePlugin();
        System.out.println("Antes de Channel");
        System.out.println(channel);
        channel.setMethodCallHandler(plugin);

        context = binding.getApplicationContext();
        activity = (Activity) context;
        System.out.println(context);
        System.out.println(activity);
        pluginbk = plugin;
        // initialize nfc stuff
        mNfcAdapter = NfcAdapter.getDefaultAdapter(context);
        System.out.println(mNfcAdapter);
        if (mNfcAdapter == null) {
            // Stop here, we need NFC
            System.out.println("No NFC");
            Toast.makeText(context, "对不起，您的设备不支持NFC，无法正常使用本软件",
                    Toast.LENGTH_LONG).show();
        } else if (!mNfcAdapter.isEnabled()) {
            System.out.println("Si NFC");
            Toast.makeText(context, "请到系统设置，开启NFC功能", Toast.LENGTH_LONG).show();
        }
        
      }

      @Override
      public void onDetachedFromEngine(FlutterPlugin.FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
      }
    
      @Override
      public void onAttachedToActivity(ActivityPluginBinding binding) {
        System.out.println("ACTIVIDAD LLAMADO 1");
        activity = (Activity) binding;
      }
    
      @Override
      public void onDetachedFromActivity() {
        // no op
      }
    
      @Override
      public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding ) {
        System.out.println("ACTIVIDAD LLAMADO 2");
        activity = (Activity) binding;
      }
    
      @Override
      public void onDetachedFromActivityForConfigChanges() {
        // no op
      }


    @Override
    public void onMethodCall(MethodCall call, Result result) {
        System.out.println(call.method);
        if (call.method.equals("readMF1")) {
            List arguments = (List) call.arguments;
            result.success(readMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2)));
        } else if (call.method.equals("writeMF1")) {
            List arguments = (List) call.arguments;
            result.success(writeMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2), (byte[]) arguments.get(3)));
        } else if (call.method.equals("isMF1Here")) {
            result.success(isMF1Here());
        } else if (call.method.equals("habilitar")) {
            habilitar();
        System.out.println("METODO HABILITAR");
        System.out.println("ACTIVITY");
        System.out.println(activity);
        System.out.println("NFCADAPTER");
        System.out.println(mNfcAdapter);
        activity = (Activity) context;
        System.out.println(context);
        mNfcAdapter.enableReaderMode(activity,new NfcAdapter.ReaderCallback () {
          @Override
          public void onTagDiscovered(Tag tag) {
            System.out.println("Fuck You");
            byte[] MF1_UID = tag.getId();
            log(MF1_UID);
            MifareClassic mfc = MifareClassic.get(tag);
            if (mfc == null) return;
            System.out.println(tag);
            currentMF1 = mfc;
            System.out.println(currentMF1);
            try {
            currentMF1.connect();
            boolean isWhite = mfc.authenticateSectorWithKeyA(2, MifareClassic.KEY_DEFAULT);
            int blockCount = mfc.getBlockCount();
            int sectorCount = mfc.getSectorCount();
            currentMF1.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
          }
        } , 1, null);
            result.success(true);
        } else if (call.method.equals("deshabilitar")) {
            mNfcAdapter.disableReaderMode(activity);
            result.success(true);
        } else {
            result.notImplemented();
        }
    }


    private static void log(String str) {
        Log.e("ttt", str);
    }

    private static void log(byte[] bytes) {
        String str = "";
        for (int i = 0; i < bytes.length; i++) {
            str += bytes[i];
            str += ",";
        }

        log(str);
    }

    private boolean writeMF1(int sectorIndex, int blockIndex, byte[] key, byte[] data) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            if (isOpen) {
                mfc.writeBlock(mfc.sectorToBlock(sectorIndex) + blockIndex, data);
                return true;
            } else {
                return false;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return false;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    private boolean isMF1Here(){
        if (currentMF1 == null) {
            return false;
        }

        try {
            currentMF1.connect();
            currentMF1.close();
            return true;
        } catch (IOException e) {
            e.printStackTrace();
            currentMF1 = null;
            return false;
        }
    }

    private void habilitar(){
        System.out.println("METODO HABILITAR FUN");
    }

    private byte[] readMF1(int sectorIndex, int blockIndex, byte[] key) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            log("is OPen" + isOpen);
            if (isOpen) {
                return mfc.readBlock(mfc.sectorToBlock(sectorIndex) + blockIndex);
            } else {
                return null;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    public void iamhere(HashMap map) {
        channel.invokeMethod("iamhere", map, new Result() {
            @Override
            public void success(Object o) {
                log("success");
            }

            @Override
            public void error(String s, String s1, Object o) {
                log("error");
            }

            @Override
            public void notImplemented() {
                log("notImplemented");
            }
        });
    }


    private boolean testKey(MifareClassic mfc, byte[] key) throws IOException {
        return mfc.authenticateSectorWithKeyA(2, key);
    }

    private byte[] getKeyByUID(byte[] MF1_UID) {
        byte[] key = new byte[6];

        key[0] = (byte) (0x81 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[1] = (byte) (0xED ^ MF1_UID[1] ^ MF1_UID[3]);
        key[2] = (byte) (0xBF ^ MF1_UID[0] ^ MF1_UID[2]);
        key[3] = (byte) (0xE8 ^ MF1_UID[1] ^ MF1_UID[3]);
        key[4] = (byte) (0xA5 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[5] = (byte) (0xFC ^ MF1_UID[1] ^ MF1_UID[3]);

        return key;
    }
}

==> 1.0.27.tar.gz: android/src/main/java/com/aruistar/flutter/plugin/flutter_nfc_mifare/FlutterNfcMifarePlugin.java <==
package com.aruistar.flutter.plugin.flutter_nfc_mifare;

import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.nfc.NfcAdapter;
import android.nfc.Tag;
import android.nfc.tech.MifareClassic;
import android.util.Log;
import android.widget.Toast;
import android.app.Activity;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.ExecutionException;

/**
 * FlutterNfcMifarePlugin
 */
public class FlutterNfcMifarePlugin implements FlutterPlugin, ActivityAware , MethodCallHandler/*, PluginRegistry.NewIntentListener*/ {

    private static NfcAdapter mNfcAdapter;
    private static PendingIntent mPendingIntent;
    private Activity activity;
    private static Context context;
    static MethodChannel channel = null;
    static MifareClassic currentMF1 = null;
    private static FlutterNfcMifarePlugin pluginbk;
    /**
     * Plugin registration.
     */

     @Override
     public void onAttachedToEngine(FlutterPluginBinding binding) {
        channel = new MethodChannel(binding.getFlutterEngine().getDartExecutor(), "flutter_nfc_mifare");
        FlutterNfcMifarePlugin plugin = new FlutterNfcMifarePlugin();
        System.out.println("Antes de Channel");
        System.out.println(channel);
        channel.setMethodCallHandler(plugin);

        context = binding.getApplicationContext();
      }

      @Override
      public void onDetachedFromEngine(FlutterPlugin.FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
      }
    
      @Override
      public void onAttachedToActivity(ActivityPluginBinding binding) {
        System.out.println("ACTIVIDAD LLAMADO 1");
        activity = (Activity) binding;
      }
    
      @Override
      public void onDetachedFromActivity() {
        // no op
      }
    
      @Override
      public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding ) {
        System.out.println("ACTIVIDAD LLAMADO 2");
        activity = (Activity) binding;
      }
    
      @Override
      public void onDetachedFromActivityForConfigChanges() {
        // no op
      }


    @Override
    public void onMethodCall(MethodCall call, Result result) {
        mNfcAdapter = NfcAdapter.getDefaultAdapter(context);
        activity = context.getActivity();
        System.out.println(mNfcAdapter);
        if (mNfcAdapter == null) {
            // Stop here, we need NFC
            System.out.println("No NFC");
        } else if (!mNfcAdapter.isEnabled()) {
            System.out.println("NFC No Habilitado");
        } else if (mNfcAdapter.isEnabled()) {
            System.out.println("NFC Habilitado");
        }
        System.out.println(call.method);
        if (call.method.equals("readMF1")) {
            List arguments = (List) call.arguments;
            result.success(readMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2)));
        } else if (call.method.equals("writeMF1")) {
            List arguments = (List) call.arguments;
            result.success(writeMF1((int) arguments.get(0), (int) arguments.get(1), (byte[]) arguments.get(2), (byte[]) arguments.get(3)));
        } else if (call.method.equals("isMF1Here")) {
            result.success(isMF1Here());
        } else if (call.method.equals("habilitar")) {
            habilitar();
        System.out.println("METODO HABILITAR");
        System.out.println("ACTIVITY");
        System.out.println(activity);
        System.out.println("NFCADAPTER");
        System.out.println(mNfcAdapter);
        activity = (Activity) context;
        System.out.println(context);
        mNfcAdapter.enableReaderMode(activity,new NfcAdapter.ReaderCallback () {
          @Override
          public void onTagDiscovered(Tag tag) {
            System.out.println("Fuck You");
            byte[] MF1_UID = tag.getId();
            log(MF1_UID);
            MifareClassic mfc = MifareClassic.get(tag);
            if (mfc == null) return;
            System.out.println(tag);
            currentMF1 = mfc;
            System.out.println(currentMF1);
            try {
            currentMF1.connect();
            boolean isWhite = mfc.authenticateSectorWithKeyA(2, MifareClassic.KEY_DEFAULT);
            int blockCount = mfc.getBlockCount();
            int sectorCount = mfc.getSectorCount();
            currentMF1.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
          }
        } , 1, null);
            result.success(true);
        } else if (call.method.equals("deshabilitar")) {
            mNfcAdapter.disableReaderMode(activity);
            result.success(true);
        } else {
            result.notImplemented();
        }
    }


    private static void log(String str) {
        Log.e("ttt", str);
    }

    private static void log(byte[] bytes) {
        String str = "";
        for (int i = 0; i < bytes.length; i++) {
            str += bytes[i];
            str += ",";
        }

        log(str);
    }

    private boolean writeMF1(int sectorIndex, int blockIndex, byte[] key, byte[] data) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            if (isOpen) {
                mfc.writeBlock(mfc.sectorToBlock(sectorIndex) + blockIndex, data);
                return true;
            } else {
                return false;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return false;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    private boolean isMF1Here(){
        if (currentMF1 == null) {
            return false;
        }

        try {
            currentMF1.connect();
            currentMF1.close();
            return true;
        } catch (IOException e) {
            e.printStackTrace();
            currentMF1 = null;
            return false;
        }
    }

    private void habilitar(){
        System.out.println("METODO HABILITAR FUN");
    }

    private byte[] readMF1(int sectorIndex, int blockIndex, byte[] key) {
        MifareClassic mfc = currentMF1;
        try {
            mfc.connect();
            boolean isOpen = mfc.authenticateSectorWithKeyA(sectorIndex, key);
            log("is OPen" + isOpen);
            if (isOpen) {
                return mfc.readBlock(mfc.sectorToBlock(sectorIndex) + blockIndex);
            } else {
                return null;
            }
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        } finally {
            try {
                mfc.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }

    public void iamhere(HashMap map) {
        channel.invokeMethod("iamhere", map, new Result() {
            @Override
            public void success(Object o) {
                log("success");
            }

            @Override
            public void error(String s, String s1, Object o) {
                log("error");
            }

            @Override
            public void notImplemented() {
                log("notImplemented");
            }
        });
    }


    private boolean testKey(MifareClassic mfc, byte[] key) throws IOException {
        return mfc.authenticateSectorWithKeyA(2, key);
    }

    private byte[] getKeyByUID(byte[] MF1_UID) {
        byte[] key = new byte[6];

        key[0] = (byte) (0x81 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[1] = (byte) (0xED ^ MF1_UID[1] ^ MF1_UID[3]);
        key[2] = (byte) (0xBF ^ MF1_UID[0] ^ MF1_UID[2]);
        key[3] = (byte) (0xE8 ^ MF1_UID[1] ^ MF1_UID[3]);
        key[4] = (byte) (0xA5 ^ MF1_UID[0] ^ MF1_UID[2]);
        key[5] = (byte) (0xFC ^ MF1_UID[1] ^ MF1_UID[3]);

        return key;
    }
}
